/* mem.c
 *
 * Copyright 2018, 2019 Bruce Cowan <bruce@bcowan.me.uk>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * SPDX-License-Identifier: Apache-2.0
 */

#ifdef HAVE_REALLOCARRAY
  #define _GNU_SOURCE
#endif

#include "config.h"
#include "mem.h"

#include <stdlib.h>

void *
check_calloc (size_t nmemb,
              size_t size)
{
  void *ptr = calloc (nmemb, size);
  if (!ptr)
    exit (EXIT_FAILURE);

  return ptr;
}

void *
check_malloc (size_t size)
{
  void *ptr = malloc (size);
  if (!ptr)
    exit (EXIT_FAILURE);

  return ptr;
}

void *
check_reallocarray (void   *ptr,
                    size_t  nmemb,
                    size_t  size)
{
#ifdef HAVE_REALLOCARRAY
  void *new = reallocarray (ptr, nmemb, size);
#else
  void *new = realloc (ptr, nmemb * size);
#endif

  if (!new)
    exit (EXIT_FAILURE);

  return new;
}
